//
//  CircleBanner.swift
//  FBWLoginTemplate
//
//  Created by Jean-Marc Boullianne on 8/28/19.
//  Copyright © 2019 Jean-Marc Boullianne. All rights reserved.
//

import UIKit

@IBDesignable class CircleBanner: UIView {

    private var circleMask = CAShapeLayer()
    
    var label:UILabel

    // Only override draw() if you perform custom drawing.
    // An empty implementation adversely affects performance during animation.
    override func draw(_ rect: CGRect) {
        // Drawing code
        
        let dist = rect.width * (0.65)
        let offset = rect.width - dist
        
        let path = UIBezierPath()
        path.move(to: CGPoint(x: 0, y: 0))
        path.move(to: CGPoint(x: dist, y: 0))
        path.addArc(withCenter: CGPoint(x: offset, y: offset), radius: dist, startAngle: 0, endAngle: 2.0 * CGFloat.pi, clockwise: true)
        path.close()
        
        circleMask.fillColor = UIColor.black.cgColor
        circleMask.path = path.cgPath
        circleMask.frame = self.bounds
        
        self.layer.backgroundColor = UIColor.clear.cgColor
        
        self.layer.insertSublayer(circleMask, below: label.layer)
        //self.layer.shadowPath = path.cgPath
        self.layer.shadowColor = UIColor.black.cgColor
        self.layer.shadowRadius = 10.0
        self.layer.shadowOpacity = 0.7
        
    }
    
    override init(frame: CGRect) {
        label = UILabel(frame: frame)
        super.init(frame: frame)
        self.addSubview(label)
        setupLabel()
        
    }
    
    required init?(coder aDecoder: NSCoder) {
        label = UILabel()
        super.init(coder: aDecoder)
        self.addSubview(label)
        setupLabel()
    }
    
    func setupLabel() {
        label.translatesAutoresizingMaskIntoConstraints = false
        label.topAnchor.constraint(equalTo: self.topAnchor).isActive = true
        label.bottomAnchor.constraint(equalTo: self.bottomAnchor).isActive = true
        label.leftAnchor.constraint(equalTo: self.leftAnchor).isActive = true
        label.rightAnchor.constraint(equalTo: self.rightAnchor).isActive = true
        
        label.textAlignment = .center
        label.textColor = UIColor.white
        
        label.text = "LOGIN"
        label.font = UIFont(name: "Avenir-Heavy", size: 35)
    }
    

    

}
