//
//  LoginTextField.swift
//  FBWLoginTemplate
//
//  Created by Jean-Marc Boullianne on 8/29/19.
//  Copyright © 2019 Jean-Marc Boullianne. All rights reserved.
//

import UIKit

@IBDesignable class LoginTextField: UIView {

    
    var iconView:UIImageView
    var inputField:UITextField
    
    var bottomLayer = CAShapeLayer()
    
    var image:UIImage? {
        get {
            return iconView.image
        }
        set(newImage) {
            let tintedImage = newImage?.withRenderingMode(.alwaysTemplate)
            iconView.image = tintedImage
            iconView.tintColor = borderColor
        }
    }
    
    var placeholderColor:UIColor = UIColor.darkGray
    var placeholder:String? {
        get {
            return inputField.placeholder
        }
        set(newPlaceholder) {
            inputField.attributedPlaceholder = NSAttributedString(string: newPlaceholder ?? "", attributes: [NSAttributedString.Key.foregroundColor:self.placeholderColor])
        }
    }
    
    var delegate:UITextFieldDelegate? {
        get {
            return self.inputField.delegate
        }
        set(newDelegate) {
            self.inputField.delegate = newDelegate
        }
    }
    
    var selectionColor:UIColor = UIColor(red: 0, green: 173/255, blue: 255/255, alpha: 1.0)
    var borderColor:UIColor = UIColor.lightGray
    
    // Only override draw() if you perform custom drawing.
    // An empty implementation adversely affects performance during animation.
    override func draw(_ rect: CGRect) {
        // Drawing code
        
        let borderRect = CGRect(x: 0, y: rect.height-2, width: rect.width, height: 1)
        let path = UIBezierPath()
        path.move(to: CGPoint(x: 0, y: rect.height-2))
        path.move(to: CGPoint(x: rect.width, y: rect.height-2))
        path.move(to: CGPoint(x: rect.width, y: rect.height-1))
        path.move(to: CGPoint(x: 0, y: rect.height-1))
        path.close()
        
        
        bottomLayer.borderColor = borderColor.cgColor
        bottomLayer.borderWidth = 1
        bottomLayer.path = path.cgPath
        bottomLayer.frame = borderRect
        
        self.layer.addSublayer(bottomLayer)
    }
    
    
    override init(frame: CGRect) {
        
        let iconFrame = CGRect(x: 0, y: 0, width: 30, height: frame.height)
        iconView = UIImageView(frame: iconFrame)
        
        let inputFrame = CGRect(x: 30, y: 0, width: frame.width-30, height: frame.height)
        inputField = UITextField(frame: inputFrame)
        super.init(frame: frame)
        
        self.addSubview(iconView)
        self.addSubview(inputField)
        
        setupSubviews()
    }
    
    required init?(coder aDecoder: NSCoder) {
        
        iconView = UIImageView()
        inputField = UITextField()
        super.init(coder: aDecoder)
        
        self.addSubview(iconView)
        self.addSubview(inputField)
        
        setupSubviews()
    }
    
    func setupSubviews() {
        iconView.translatesAutoresizingMaskIntoConstraints = false
        iconView.leftAnchor.constraint(equalTo: self.leftAnchor).isActive = true
        iconView.topAnchor.constraint(equalTo: self.topAnchor).isActive = true
        iconView.bottomAnchor.constraint(equalTo: self.bottomAnchor).isActive = true
        iconView.widthAnchor.constraint(equalToConstant: 18).isActive = true
    
        self.image = UIImage(named: "User-Icon")
        iconView.contentMode = .scaleAspectFit
        //iconView.backgroundColor = UIColor.blue
        
        inputField.translatesAutoresizingMaskIntoConstraints = false
        inputField.rightAnchor.constraint(equalTo: self.rightAnchor).isActive = true
        inputField.topAnchor.constraint(equalTo: self.topAnchor).isActive = true
        inputField.bottomAnchor.constraint(equalTo: self.bottomAnchor).isActive = true
        inputField.leftAnchor.constraint(equalTo: self.iconView.rightAnchor, constant: 18).isActive = true
        //inputField.backgroundColor = UIColor.red
        inputField.textAlignment = .left
        inputField.font = UIFont(name: "Avenir-Heavy", size: 17)
        inputField.spellCheckingType = .no
        
        self.placeholder = "Placeholder"
        
        inputField.addTarget(self, action: #selector(inputActive), for: .editingDidBegin)
        inputField.addTarget(self, action: #selector(inputEnded), for: .editingDidEnd)
        
    }
    
    @objc func inputActive() {
        self.bottomLayer.borderColor = selectionColor.cgColor
        self.iconView.tintColor = selectionColor
    }
    
    @objc func inputEnded() {
        self.bottomLayer.borderColor = borderColor.cgColor
        self.iconView.tintColor = borderColor
    }

}


