//
//  ViewController.swift
//  FBWLoginTemplate
//
//  Created by Jean-Marc Boullianne on 8/28/19.
//  Copyright © 2019 Jean-Marc Boullianne. All rights reserved.
//

import UIKit

class ViewController: UIViewController {

    @IBOutlet weak var bannerView: CircleBanner!
    @IBOutlet weak var appIconView: AppIconView!
    
    @IBOutlet weak var usernameField: LoginTextField!
    @IBOutlet weak var passwordField: LoginTextField!
    @IBOutlet weak var emailField: LoginTextField!
    
    @IBOutlet weak var submitButton: UIButton!
    @IBOutlet weak var formButton: UIButton!
    @IBOutlet weak var formLabel: UILabel!
    
    var signupEnabled = false
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        // Setup App Icon Image
        appIconView.iconView.image = UIImage(named: "FBWIcon")
        
        //Set Image For Input Fields
        usernameField.image = UIImage(named: "User-Icon")
        passwordField.image = UIImage(named: "Key-Icon")
        emailField.image = UIImage(named: "Mail-Icon")
        
        // Set Text Field Content Types
        usernameField.inputField.textContentType = .username
        passwordField.inputField.textContentType = .password
        passwordField.inputField.isSecureTextEntry = true
        emailField.inputField.textContentType = .emailAddress
        
        // Setup Placeholders
        usernameField.placeholder = "Username"
        passwordField.placeholder = "Password"
        emailField.placeholder = "Email"
        
        // Set ViewController as delegate for Input Fields
        usernameField.delegate = self
        passwordField.delegate = self
        emailField.delegate = self
        
        if signupEnabled {
            transitionToSignup()
        } else {
            transitionToLogin()
        }
    }
    
    override func viewDidLayoutSubviews() {
        super.viewDidLayoutSubviews()
        submitButton.layer.cornerRadius = 5
    }
    
    func transitionToSignup() {
        print("TTS")
        UIView.animate(withDuration: 0.2) {
            self.bannerView.label.text = "SIGNUP"
            self.submitButton.setTitle("SIGNUP", for: .normal)
            self.formButton.setTitle("Login", for: .normal)
            self.formLabel.text = "Have an account already?"
            self.emailField.transform = .identity
            self.view.layoutIfNeeded()
        }
        self.view.layoutIfNeeded()
    }
    
    func transitionToLogin() {
        print("TTL")
        UIView.animate(withDuration: 0.2) {
            self.bannerView.label.text = "LOGIN"
            self.submitButton.setTitle("LOGIN", for: .normal)
            self.formButton.setTitle("Signup", for: .normal)
            self.formLabel.text = "Don't have an account?"
            self.emailField.transform = self.emailField.transform.translatedBy(x: self.view.frame.width, y: 0)
            self.view.layoutIfNeeded()
        }
        self.view.layoutIfNeeded()
    }

    @IBAction func formButtonPressed(_ sender: Any) {
        print("Form Button Pressed", signupEnabled)
        if signupEnabled {
            transitionToLogin()
        } else {
            transitionToSignup()
        }
        
        signupEnabled = !signupEnabled
    }
    
    // Put Action Code here... to submit user credentials
    @IBAction func submitButtonPressed(_ sender: Any) {
        
        let username = usernameField.inputField.text
        let password = passwordField.inputField.text
        let email = emailField.inputField.text
        
        print("Form Submitted:", username ?? "", password ?? "", email ?? "")
    }
    
    @IBAction func didTapBackground(_ sender: Any) {
        if usernameField.inputField.isFirstResponder { usernameField.inputField.resignFirstResponder()}
        if passwordField.inputField.isFirstResponder { passwordField.inputField.resignFirstResponder()}
        if emailField.inputField.isFirstResponder { emailField.inputField.resignFirstResponder()}
    }
}

extension ViewController: UITextFieldDelegate {
    
    func textFieldShouldReturn(_ textField: UITextField) -> Bool {
        switch textField {
        case usernameField.inputField:
            usernameField.inputField.resignFirstResponder()
            passwordField.inputField.becomeFirstResponder()
        case passwordField.inputField:
            passwordField.inputField.resignFirstResponder()
            
            if signupEnabled {
                emailField.inputField.becomeFirstResponder()
            }
        case emailField.inputField:
            emailField.inputField.resignFirstResponder()
        default:
            break
        }
        
        return true
    }
}

